@@ -20,7 +20,7 @@
 
 package App::MtAws::ConfigDefinition;
 
-our $VERSION = "1.112_5";
+our $VERSION = "1.114_1";
 
 use strict;
 use warnings;
@@ -356,8 +356,6 @@ sub get_config
 			validation $_, $must_be_an_integer, stop => 1, sub { $_ =~ /^\d+$/ };
 			validation $_, message('Part size must be power of two'), sub { ($_ != 0) && (($_ & ($_ - 1)) == 0) };
 			validation $_, message('%option a% must be less or equal to 4096'), sub { $_ <= 4096 };
-			validation $_, message('On 32 bit systems, when Digest::SHA module version < 5.62, %option a% must be less or equal to 256'),
-				sub { !is_digest_sha_broken_for_large_data() || $_ <= 256 };
 		}
 		for (option('segment-size', type => 'i')) {
 			validation $_, $must_be_an_integer, stop => 1, sub { $_ =~ /^\d+$/ };
