@@ -20,7 +20,7 @@
 
 package App::MtAws::Journal;
 
-our $VERSION = '1.112_5';
+our $VERSION = '1.114_1';
 
 use strict;
 use warnings;
@@ -158,7 +158,7 @@ sub process_line
 		});
 		$self->{used_versions}->{$ver} = 1 unless $self->{used_versions}->{$ver};
 	} elsif (($ver, $time, $archive_id, $relfilename) = $line =~ /^([ABC])\t([0-9]{1,20})\tDELETED\t(\S+)\t(.*?)$/) {
-		$self->_delete_archive($archive_id); # TODO avoid stuff like $1 $2 $3 etc
+		$self->_delete_archive($archive_id, $relfilename);
 		$self->{used_versions}->{$ver} = 1 unless $self->{used_versions}->{$ver};
 	} elsif (($ver, $time, $archive_id, $job_id) = $line =~ /^([ABC])\t([0-9]{1,20})\tRETRIEVE_JOB\t(\S+)\t(.*?)$/) {
 		$self->_retrieve_job($time+0, $archive_id, $job_id);
@@ -178,8 +178,8 @@ sub process_line
 			treehash => $treehash,
 		});
 		$self->{used_versions}->{0} = 1 unless $self->{used_versions}->{0};
-	} elsif ($line =~ /^[0-9]{1,20}\s+DELETED\s+(\S+)\s+(.*?)$/) { # TODO: delete file, parse time too!
-		$self->_delete_archive($1);
+	} elsif (($archive_id, $relfilename) = $line =~ /^[0-9]{1,20}\s+DELETED\s+(\S+)\s+(.*?)$/) { # TODO: delete file, parse time too!
+		$self->_delete_archive($archive_id, $relfilename);
 		$self->{used_versions}->{0} = 1 unless $self->{used_versions}->{0};
 	} elsif (($time, $archive_id) = $line =~ /^([0-9]{1,20})\s+RETRIEVE_JOB\s+(\S+)$/) {
 		$self->_retrieve_job($time+0, $archive_id);
@@ -199,7 +199,7 @@ sub process_line
 sub _add_archive
 {
 	my ($self, $args) = @_;
-	if (!$self->{filter} || $self->{filter}->check_filenames($args->{relfilename})) {
+	if ($self->check_filenames($args->{relfilename})) {
 		confess "duplicate entry" if $self->{archive_h}{$args->{archive_id}};
 		$self->{archive_h}{$args->{archive_id}} = $args;
 	}
@@ -207,9 +207,15 @@ sub _add_archive
 
 sub _delete_archive
 {
-	my ($self, $archive_id) = @_;
-	$self->{archive_h}{$archive_id} or confess "archive $archive_id not found in archive_h"; # TODO: put it to backlog, process later?
-	delete $self->{archive_h}{$archive_id};
+	my ($self, $archive_id, $relfilename) = @_;
+	confess unless defined $archive_id && defined $relfilename;
+
+	if ($self->{archive_h}{$archive_id}) {
+		delete $self->{archive_h}{$archive_id}; # archive_id found, deleting it without checking filename filter
+	} else {
+		confess "archive $archive_id not found in archive_h" # not found - confess, unless it's excluded by filter
+			if $self->check_filenames($relfilename); # TODO: put it to backlog, process later?
+	}
 }
 
 sub _add_filename
@@ -345,7 +351,7 @@ sub read_files
 			# file can be not existing here (i.e. dangling symlink)
 			my $filename = character_filename(my $binaryfilename = $_);
 			my $orig_relfilename = abs2rel($filename, $self->{root_dir}, allow_rel_base => 1);
-			if (!$self->{filter} || $self->{filter}->check_filenames($orig_relfilename)) {
+			if ($self->check_filenames($orig_relfilename)) {
 				if ($self->_is_file_exists($binaryfilename)) {
 					my $relfilename;
 					confess "Invalid filename: ".hex_dump_string($orig_relfilename)
@@ -435,6 +441,10 @@ sub _can_read_filename_for_mode
 	}
 }
 
-
+sub check_filenames
+{
+	my $self = shift;
+	!$self->{filter} || $self->{filter}->check_filenames(@_)
+}
 
 1;
